/*
 * Copyright 2008 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.spi;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * <p>A meta-annotation that specifies that an annotation should be used to 
 * generate a service provider configuration</p>
 * 
 * <p>Use this annotation to create annotations that will generate service 
 * provider configuration entries for specific services</p>
 * 
 * <p>For instance, if the user has a specific service, 
 * {@code DictionaryService}, that is configured with a {@code DictionaryInfo} 
 * annotation, placing<br/><br/>
 * 
 * <code>
 *   &#064;ServiceProviderAnnotation(DictionaryService.class)<br/><br/>
 * </code>
 * 
 * upon the {@code DicationaryInfo} annotation will cause the annotation 
 * processor to create service provider configurations for each subtype of 
 * {@code DictionaryService} annotated with <code>&#064;DictionaryInfo</code>.
 * </p>
 * 
 * @author Evan Cowden
 */
@Documented
@Retention(RetentionPolicy.SOURCE)
@Target(ElementType.ANNOTATION_TYPE)
public @interface ServiceProviderAnnotation {

    /**
     * The service interface implied by the presence of this annotation
     */
    public Class<?> value();
}
