/*
 * Copyright 2008 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.spi.processors;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

/**
 * A <i>very</i> basic multimap that maps keys to a collection of values
 * @author Evan Cowden
 */
class SimpleMultiMap<K, V> {

    private Map<K, Collection<V>> map = new HashMap<K, Collection<V>>();

    public Collection<Collection<V>> values() {
        return map.values();
    }

    public int size() {
        return map.size();
    }

    public Collection<V> remove(Object key) {
        return map.remove(key);
    }

    public Set<K> keySet() {
        return map.keySet();
    }

    public boolean isEmpty() {
        return map.isEmpty();
    }

    public int hashCode() {
        return map.hashCode();
    }

    public Collection<V> get(Object key) {
        return map.get(key);
    }

    public boolean equals(Object o) {
        return map.equals(o);
    }

    public Set<Entry<K, Collection<V>>> entrySet() {
        return map.entrySet();
    }

    public boolean containsValue(Object value) {
        return map.containsValue(value);
    }

    public boolean containsKey(Object key) {
        return map.containsKey(key);
    }

    public void clear() {
        map.clear();
    }

    public void putAll(K key, Collection<V> values) {
        Collection<V> mapValues = map.get(key);
        if (mapValues == null) {
            mapValues = new ArrayList<V>();
            map.put(key, mapValues);
        }
        mapValues.addAll(values);
    }

    public Collection<V> put(K key, V value) {
        Collection<V> values = map.get(key);
        if (values == null) {
            values = new ArrayList<V>();
            map.put(key, values);
        }
        values.add(value);

        return values;
    }
}
